package com.zanxiang.manage.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.zanxiang.common.domain.ResultVO;
import com.zanxiang.erp.security.annotation.PreAuthorize;
import com.zanxiang.manage.domain.params.PromoAccountAddUpdateParam;
import com.zanxiang.manage.domain.params.PromoAccountAssignParam;
import com.zanxiang.manage.domain.params.PromoAccountListParam;
import com.zanxiang.manage.domain.vo.PromoAccountListVO;
import com.zanxiang.manage.service.PromoAccountService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author : lingfeng
 * @time : 2022-11-21
 * @description : 推广账号
 */
@Api(tags = "推广账号接口")
@RestController
@RequestMapping("/promo/account")
public class PromoAccountController {

    @Autowired
    private PromoAccountService promoAccountService;

    @ApiOperation(value = "查询推广账号列表")
    @PostMapping(value = "/list")
    @PreAuthorize(permissionKey = "manage:promoAccount:list")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = PromoAccountListVO.class)})
    public ResultVO<IPage<PromoAccountListVO>> list(@Validated @RequestBody PromoAccountListParam param) {
        return ResultVO.ok(promoAccountService.list(param));
    }

    @ApiOperation(value = "推广账号添加或修改")
    @PostMapping(value = "/add/or/update")
    @PreAuthorize(permissionKey = "manage:promoAccount:addOrUpdate")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> addOrUpdate(@Validated @RequestBody PromoAccountAddUpdateParam param) {
        return ResultVO.ok(promoAccountService.addOrUpdate(param));
    }

    @ApiOperation(value = "推广账号状态变更")
    @PatchMapping(value = "/status/update")
    @PreAuthorize(permissionKey = "manage:promoAccount:statusUpdate")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> statusUpdate(@RequestParam Long id, @RequestParam Integer status) {
        return new ResultVO<>(promoAccountService.statusUpdate(id, status));
    }

    @ApiOperation(value = "推广账号指派")
    @PostMapping(value = "/assign")
    @PreAuthorize(permissionKey = "manage:accountAssign:addOrUpdate")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> accountAssign(@Validated @RequestBody PromoAccountAssignParam param) {
        return ResultVO.ok(promoAccountService.accountAssign(param));
    }
}
