package com.zanxiang.manage.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.zanxiang.manage.domain.dto.PromoAccountDTO;
import com.zanxiang.manage.domain.params.PromoAccountAddUpdateParam;
import com.zanxiang.manage.domain.params.PromoAccountAssignParam;
import com.zanxiang.manage.domain.params.PromoAccountListParam;
import com.zanxiang.manage.domain.vo.PromoAccountChoiceVO;
import com.zanxiang.manage.domain.vo.PromoAccountLinkageChoiceVO;
import com.zanxiang.manage.domain.vo.PromoAccountListVO;
import com.zanxiang.manage.domain.vo.PromoPitcherChoiceVO;
import com.zanxiang.mybatis.entity.PromoAccount;

import java.util.List;
import java.util.Map;

/**
 * @author : lingfeng
 * @time : 2022-11-04
 * @description : 推广账号
 */
public interface PromoAccountService extends IService<PromoAccount> {

    /**
     * 获取账号联动选择列表
     *
     * @return : 返回列表
     */
    List<PromoAccountLinkageChoiceVO> promoAccountLinkageChoiceList();

    /**
     * 查询推广媒体列表
     *
     * @param param : 推广媒体列表查询参数
     * @return : 返回分页信息
     */
    IPage<PromoAccountListVO> list(PromoAccountListParam param);

    /**
     * 推广账号新增或者更新
     *
     * @param param : 更新参数
     * @return : 返回结果
     */
    Boolean addOrUpdate(PromoAccountAddUpdateParam param);

    /**
     * 帐户分配
     *
     * @param param 参数
     * @return {@link Boolean}
     */
    Boolean accountAssign(PromoAccountAssignParam param);

    /**
     * 根据主键更新状态
     *
     * @param id     : 主键id
     * @param status : 状态
     * @return : 返回更新结果
     */
    Boolean statusUpdate(Long id, Integer status);

    /**
     * 推广账号选择列表查询
     *
     * @return : 返回所有推广账号信息
     */
    List<PromoAccountChoiceVO> promoAccountChoiceList();

    /**
     * 投手选择列表查询
     *
     * @return : 返回所有投手信息
     */
    List<PromoPitcherChoiceVO> promoPitcherChoiceList();

    /**
     * 通过帐户或投手id列表
     *
     * @param account   账户
     * @param pitcherId 投手id
     * @return {@link List}<{@link Long}>
     */
    List<Long> listByAccountOrPitcherId(String account, String pitcherId);

    /**
     * 注册渠道信息
     *
     * @return : 返回所有渠道信息
     */
    Map<Long, PromoAccountDTO> promoAccountMap();

    /**
     * 推广账号条件
     *
     * @param pitcherGroupId 投手组id
     * @param pitcherId      投手id
     * @param mediaId        媒体id
     * @param accountType    帐户类型
     */
    Map<Long, PromoAccountDTO> promoAccountCondition(String pitcherGroupId, String pitcherId, Long mediaId, String account, Integer accountType);
}
